## PAVES 0.9.1: 2026-02-17

- Update for PLAYA 1.0
- Add newer layout detection models (which you are not required to use)
- Refactor image and table code

## PAVES 0.8.0: sometime in the past

- Correct and improve text extraction
- Correct various problems with table detection
- Remove "bears" API that I never used for anything
